@@ -15,6 +15,17 @@ from .visitor import RefurbVisitor
 class Cli:
     files: list[str] | None = None
     explain: int | None = None
+    ignore: set[int] | None = None
+    debug: bool = False
+
+
+def parse_error_id(err: str) -> int:
+    id = err.replace("FURB", "")
+
+    if id.isdigit():
+        return int(id)
+
+    raise ValueError(f'refurb: "{id}" must be in form FURB123 or 123')
 
 
 def parse_args(args: list[str]) -> Cli:
@@ -25,25 +36,39 @@ def parse_args(args: list[str]) -> Cli:
         if len(args) != 2:
             raise ValueError("usage: refurb --explain ID")
 
-        id = args[1].replace("FURB", "")
+        return Cli(explain=parse_error_id(args[1]))
 
-        if not id.isdigit():
-            raise ValueError(f'refurb: "{id}" must be in form FURB123 or 123')
+    iargs = iter(args)
+    files: list[str] = []
+    ignore: set[int] = set()
+    debug = False
 
-        return Cli(explain=int(id))
+    for arg in iargs:
+        if arg == "--debug":
+            debug = True
 
-    for arg in args:
-        if arg.startswith("-"):
+        elif arg == "--ignore":
+            value = next(iargs, None)
+
+            if value is None:
+                raise ValueError(f'refurb: missing argument after "{arg}"')
+
+            ignore.add(parse_error_id(value))
+
+        elif arg.startswith("-"):
             raise ValueError(f'refurb: unsupported option "{arg}"')
 
-    return Cli(files=args)
+        else:
+            files.append(arg)
+
+    return Cli(files=files, ignore=ignore or None, debug=debug)
 
 
-def run_refurb(filenames: list[str]) -> Sequence[Error | str]:
+def run_refurb(cli: Cli) -> Sequence[Error | str]:
     stderr = StringIO()
 
     try:
-        files, opt = process_options(filenames, stderr=stderr)
+        files, opt = process_options(cli.files or [], stderr=stderr)
 
     except SystemExit:
         return ["refurb: " + err for err in stderr.getvalue().splitlines()]
@@ -65,7 +90,10 @@ def run_refurb(filenames: list[str]) -> Sequence[Error | str]:
 
     for file in files:
         if tree := result.graph[file.module].tree:
-            rv = RefurbVisitor()
+            if cli.debug:
+                print(tree)
+
+            rv = RefurbVisitor(cli.ignore)
 
             tree.accept(rv)
 
@@ -74,22 +102,31 @@ def run_refurb(filenames: list[str]) -> Sequence[Error | str]:
 
             errors += rv.errors
 
-    return errors
+    return sorted(errors, key=sort_errors)
 
 
-def main(args: list[str]) -> None:
+def sort_errors(error: Error | str) -> tuple[int, int, int] | str:
+    if isinstance(error, str):
+        return error
+
+    return (error.line, error.column, error.code)
+
+
+def main(args: list[str]) -> int:
     try:
         cli = parse_args(args)
 
     except ValueError as e:
         print(e)
-        return
+        return 1
 
     if cli.explain:
         print(explain(cli.explain))
-        return
+        return 0
 
-    errors = run_refurb(cli.files or [])
+    errors = run_refurb(cli)
 
     for error in errors:
         print(error)
+
+    return 1 if errors else 0
